DsoAsyncArgs

Struct DsoAsyncArgs 

pub struct DsoAsyncArgs {
    pub incoming: Vec<NamespaceEntry>,
    pub outgoing_dir: Option<ServerEnd<DirectoryMarker>>,
    pub dispatcher: DispatcherRef<'static>,
    pub lifecycle: ServerEnd<LifecycleMarker>,
    pub config: Option<Vmo>,
}
Arguments to an async DSO main()

Fields

incoming: Vec<NamespaceEntry>

The component’s incoming namespace.

outgoing_dir: Option<ServerEnd<DirectoryMarker>>

The component’s outgoing directory. This is an Option but should typically be present.

dispatcher: DispatcherRef<'static>

A reference to the dispatcher used to dispatch the component’s tasks.

lifecycle: ServerEnd<LifecycleMarker>

The component’s lifecycle server handle. It can close this channel to signal component exit.

config: Option<Vmo>

The component’s structured config VMO, if it has one.